@@ -1,8 +1,8 @@
 <?php
 /*
- * $Horde: kronolith/addevent.php,v 1.30 2001/09/18 16:03:50 jan Exp $
+ * $Horde: kronolith/addevent.php,v 1.31.2.3 2003/02/11 00:41:46 jan Exp $
  *
- * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -23,17 +23,16 @@ if (!$timestamp = Horde::getFormData('timestamp')) {
 $url = Horde::getFormData('url');
 
 $event->setStartTimestamp($timestamp);
-$event->setEndTimestamp($timestamp);
+$event->setEndTimestamp($timestamp + 3600);
 $event->setRecurType(KRONOLITH_RECUR_NONE);
 $month = date('n', $timestamp);
 $year = date('Y', $timestamp);
 
 $title = _("Add a new event");
+$js_onLoad = null;
 
-require $registry->getTemplatePath() . '/common-header.inc';
-require './menu.php';
-require $registry->getTemplatePath() . '/edit/javascript.inc';
-require $registry->getTemplatePath() . '/edit/edit.inc';
-require $registry->getTemplatePath() . '/common-footer.inc';
-
-?>
+require KRONOLITH_TEMPLATES . '/common-header.inc';
+require KRONOLITH_BASE . '/menu.php';
+require KRONOLITH_TEMPLATES . '/edit/javascript.inc';
+require KRONOLITH_TEMPLATES . '/edit/edit.inc';
+require KRONOLITH_TEMPLATES . '/common-footer.inc';
